@@ -270,6 +270,10 @@ def try_decoding(data, encoding):
 
 
 def format_size(num, format_str='{num:.1f} {unit}'):
+    '''Format the file size into a human readable text.
+
+    http://stackoverflow.com/a/1094933/1524507
+    '''
     for unit in ('B', 'KiB', 'MiB', 'GiB'):
         if num < 1024 and num > -1024:
             return format_str.format(num=num, unit=unit)
